`juliet` is being developed by `Nestor Espinoza (@nespinoza)
<https://github.com/nespinoza>`_ and `Diana Kossakowski (@dianadianadiana)
<https://github.com/dianadianadiana>`_.

Contributions have been made by several authors, including `Johannes Buchner (@JohannesBuchner) <https://github.com/JohannesBuchner>`_, `Jonas Kemmer (@JonasKemmer) <https://github.com/JonasKemmer>`_, `Martin Schlecker (@matiscke) <https://github.com/matiscke>`_, `Jose Vines (@jvines) <https://github.com/jvines>`_ and `Ian Weaver (@icweaver) <https://github.com/icweaver>`_.

Want to contribute? Grab a `project <https://github.com/nespinoza/juliet/issues>`_, create your own and open a `pull request <https://github.com/nespinoza/juliet/pulls>`_!
